@@ -3,9 +3,11 @@ from django import forms
 from django.dispatch import receiver
 from django.urls import resolve, reverse
 from django.utils.translation import gettext_lazy, gettext_noop
+from functools import partial
 from i18nfield.strings import LazyI18nString
 from pretix.base.settings import settings_hierarkey
 from pretix.base.signals import (
+    layout_text_variables,
     logentry_display,
     order_canceled,
     order_expired,
@@ -170,3 +172,21 @@ def logentry_display(sender, logentry, **kwargs):
     data = json.loads(logentry.data)
 
     return locales[logentry.action_type].format_map(data)
+
+
+@receiver(layout_text_variables, dispatch_uid="matrix_inviter_layout_text_variables")
+def layout_text_variables(sender, *args, **kwargs):
+    def get_matrix_id(orderposition, order, event):
+        return str(
+            orderposition.meta_info_data.get("question_form_data", {}).get(
+                "matrix_inviter_matrix_id"
+            )
+        )
+
+    return {
+        "matrix_id": {
+            "label": gettext_lazy("Matrix ID"),
+            "editor_sample": gettext_lazy("@username:homeserver.tld"),
+            "evaluate": partial(get_matrix_id),
+        },
+    }
